@@ -30,7 +30,8 @@ class Relaxation__Vasp__Quality02(VaspWorkflow):
     confirm_convergence = False
 
     # Make the unitcell relatively cubic before relaxing
-    pre_sanitize_structure = True
+    standardize_structure = "primitive-LLL"
+    symmetry_tolerance = 0.1
 
     # These are all input settings for this task.
     incar = dict(
