@@ -33,7 +33,8 @@ class Relaxation__Vasp__Quality04(VaspWorkflow):
     confirm_convergence = False
 
     # Make the unitcell relatively cubic before relaxing
-    pre_sanitize_structure = True
+    standardize_structure = "primitive-LLL"
+    symmetry_tolerance = 0.1
 
     # These are all input settings for this task.
     incar = dict(
