@@ -6,7 +6,6 @@ database backend being used.
 """
 
 import os
-import sys
 from pathlib import Path
 
 import dj_database_url  # needed for DigitalOcean database connection
@@ -15,9 +14,6 @@ import yaml
 from simmate import website  # needed to specify location of built-in apps
 from simmate.utilities import get_conda_env, get_directory
 
-# from django.core.management.utils import get_random_secret_key
-
-
 # --------------------------------------------------------------------------------------
 
 # SET MAIN DIRECTORIES
@@ -59,12 +55,9 @@ DEBUG = os.getenv("DEBUG", "True") == "True"
 # enviornment variable isn't set yet, then we just defaul to the localhost.
 ALLOWED_HOSTS = os.getenv("DJANGO_ALLOWED_HOSTS", "127.0.0.1,localhost").split(",")
 
-# This decides wether we use a local sqlite database. The order of priority for
-# databases goes...
-#   (1) Check for a "database.yaml" file in the user's home directory
-#   (2) Check for the USE_LOCAL_DATABASE enviornment variable (defaults to True)
-#   (3) If USE_LOCAL_DATABASE=False, then check for DATABASE_URL enviornment variable
-USE_LOCAL_DATABASE = os.getenv("USE_LOCAL_DATABASE", "True") == "True"
+# This is for setting the database via an connection URL. This is done as
+# an environment variable to allow setup with DigitalOcean
+DATABASE_URL = os.getenv("DATABASE_URL", None)
 # this is not a typical Django setting
 
 # Keep the secret key used in production secret!
@@ -75,16 +68,32 @@ SECRET_KEY = os.getenv(
 )
 # !!! I removed get_random_secret_key() so I don't have to sign out every time
 # while testing my server. I may change this back in the future.
+# from django.core.management.utils import get_random_secret_key
 
 # --------------------------------------------------------------------------------------
 
 # DATBASE CONNECTION
 
+# Normally in Django, you can set the database like so: (using Postgres)
+# DATABASES = {
+#     "default": {
+#         "ENGINE": "django.db.backends.postgresql_psycopg2",
+#         "NAME": "simmate-database-pool",  # default on DigitalOcean is defaultdb
+#         "USER": "doadmin",
+#         "PASSWORD": "dibi5n3varep5ad8",
+#         "HOST": "db-postgresql-nyc3-09114-do-user-8843535-0.b.db.ondigitalocean.com",
+#         "PORT": 25061,
+#         "OPTIONS": {"sslmode": "require"},
+#         # "CONN_MAX_AGE": 0,  # set this to higher value for production website server
+#     }
+# }
+# But this section instead determines the database through a series of checks.
+
 # There are three types of database files that we check for -- in order of priority:
 #   1. database.yaml
 #   2. my_env-database.yaml
-#   3. my_env-database.sqlite3 (if USE_LOCAL_DATABASE=True) <-- and create this if doesn't exist
-#   4. use a DATABASE_URL env variable
+#   3. use a DATABASE_URL env variable
+#   4. my_env-database.sqlite3 <-- and create this if doesn't exist
 DATABASE_YAML = SIMMATE_DIRECTORY / "database.yaml"
 CONDA_DATABASE_YAML = SIMMATE_DIRECTORY / f"{CONDA_ENV}-database.yaml"
 CONDA_DATABASE_SQLITE3 = SIMMATE_DIRECTORY / f"{CONDA_ENV}-database.sqlite3".strip("-")
@@ -102,10 +111,18 @@ elif CONDA_DATABASE_YAML.exists():
     with CONDA_DATABASE_YAML.open() as file:
         DATABASES = yaml.full_load(file)
 
-# This is the default behavior
-# Our 3rd prioirity is a local sqlite database name "my_env-database.sqlite3"
 
-elif USE_LOCAL_DATABASE is True:
+# Our 3rd prioirity is Digital Ocean setup.
+# Lastly, if we make it to this point, we are likely using DigitalOcean and
+# running a server. Here, we simply require a ENV variable to be set.
+elif DATABASE_URL:
+    DATABASES = {
+        "default": dj_database_url.parse(DATABASE_URL),
+    }
+
+# Our final prioirity is a local sqlite database name "my_env-database.sqlite3".
+# This is the default setting used when simmate is first installed.
+else:
     DATABASES = {
         "default": {
             "ENGINE": "django.db.backends.sqlite3",
@@ -113,34 +130,6 @@ elif USE_LOCAL_DATABASE is True:
         }
     }
 
-# Lastly, if we make it to this point, we are likely using DigitalOcean and
-# running a server. When DigitalOcean runs the "collectstatic" command, we don't
-#  want to connect any database. So we use the "sys" library to look at the
-# command and ensure it doesn't involve "collectstatic". Otherwise we use the
-# URL that is set with our enviornment variable.
-elif len(sys.argv) > 0 and sys.argv[1] != "collectstatic":
-    # ensure that we have the database URL properly configured in DigitalOcean
-    if os.getenv("DATABASE_URL", None) is None:
-        raise Exception("DATABASE_URL environment variable not defined")
-    # Now connect our DigitalOcean to this database!
-    DATABASES = {
-        "default": dj_database_url.parse(os.environ.get("DATABASE_URL")),
-    }
-
-# Here is an example of connecting to a Postgres server normally...
-# DATABASES = {
-#     "default": {
-#         "ENGINE": "django.db.backends.postgresql_psycopg2",
-#         "NAME": "simmate-database-pool",  # default on DigitalOcean is defaultdb
-#         "USER": "doadmin",
-#         "PASSWORD": "dibi5n3varep5ad8",
-#         "HOST": "db-postgresql-nyc3-09114-do-user-8843535-0.b.db.ondigitalocean.com",
-#         "PORT": 25061,
-#         "OPTIONS": {"sslmode": "require"},  # !!! is this needed?
-#         # "CONN_MAX_AGE": 0,  # set this to higher value for production website server
-#     }
-# }
-
 # --------------------------------------------------------------------------------------
 
 # INSTALLED APPS
