@@ -11,10 +11,11 @@ calculation.
 As your need grow, you may need more complex Workflows. For complex workflows that
 require several calculations, other python logic, and parallelization, make
 sure you read through the documentation for 
-[the Workflow class](https://jacksund.github.io/simmate/simmate/workflow_engine/workflow.html) as well as relevent subclasses like the
-[S3Workflow](https://jacksund.github.io/simmate/simmate/workflow_engine/s3_workflow.html)
+[the Workflow class](https://jacksund.github.io/simmate/full_guides/workflows/overview/) 
+as well as relevent subclasses like the
+[S3Workflow](https://jacksund.github.io/simmate/full_guides/workflows/s3_workflows/)
 or 
-[VaspWorkflow](https://jacksund.github.io/simmate/simmate/calculators/vasp/tasks/base.html)
+[VaspWorkflow](https://jacksund.github.io/simmate/full_guides/workflows/third_party_software/vasp/overview/)
 """
 
 from simmate.calculators.vasp.error_handlers import (  # There are many more available too!
@@ -72,7 +73,7 @@ class Relaxation__Vasp__MyExample2(VaspWorkflow):
         # These settings are the same for all structures regardless of composition.
         PREC="Normal",
         EDIFF=1e-5,
-        ENCUT=450,  # !!! Should this be based on the element type?
+        ENCUT=450,
         ISIF=3,
         NSW=100,
         IBRION=1,
