@@ -29,6 +29,7 @@ from django.db import models  # , transaction
 from django.db import models as table_column
 from django.utils.timezone import datetime
 from django_pandas.io import read_frame
+from rich.progress import track
 
 
 class SearchResults(models.QuerySet):
@@ -148,7 +149,7 @@ class SearchResults(models.QuerySet):
             today = datetime.today()
             filename_base = "-".join(
                 [
-                    self.model.__name__,
+                    self.model.table_name,
                     str(today.year),
                     str(today.month).zfill(2),
                     str(today.day).zfill(2),
@@ -366,11 +367,15 @@ class DatabaseTable(models.Model):
     """
 
     @classmethod
-    def get_table_name(cls) -> str:
+    @property
+    def table_name(cls) -> str:
         """
         Returns the name of this database table, which will simply match the
-        class name. Using `Table.__name__` is often easier. This method simply
-        makes the name accessible in Django Templates.
+        class name.
+
+        Note, we use "table_name" instead of "name" because users may want
+        a column titled "name", which would break features. To reduce
+        occurance of of this issue, we use "table_name" instead.
         """
         return cls.__name__
 
@@ -592,8 +597,6 @@ class DatabaseTable(models.Model):
             confirm_sqlite_parallel,
         )
 
-        from tqdm import tqdm
-
         from simmate.toolkit import Structure as ToolkitStructure
 
         # generate the file name if one wasn't given
@@ -604,12 +607,12 @@ class DatabaseTable(models.Model):
             matching_files = [
                 file
                 for file in Path.cwd().iterdir()
-                if file.name.startswith(cls.__name__) and file.suffix == ".zip"
+                if file.name.startswith(cls.table_name) and file.suffix == ".zip"
             ]
             # make sure there is at least one file
             if not matching_files:
                 raise FileNotFoundError(
-                    f"No file found matching the {cls.__name__}-*.zip format"
+                    f"No file found matching the {cls.table_name}-*.zip format"
                 )
             # sort the files by date and grab the first
             matching_files.sort(reverse=True)
@@ -673,8 +676,8 @@ class DatabaseTable(models.Model):
         # now iterate through all entries to save them to the database
         if not parallel:
             # If user doesn't want parallelization, we run these in the main
-            # thread and monitor progress with tqdm
-            for entry in tqdm(entries):
+            # thread and monitor progress
+            for entry in track(entries):
                 load_single_entry(entry)
         # otherwise we use dask to submit these in batches!
         else:
@@ -766,7 +769,7 @@ class DatabaseTable(models.Model):
         logging.info("Done.")
 
         # now that the archive is downloaded, we can load it into our db
-        logging.info("Loading data into Simmate database...")
+        logging.info("Loading data into Simmate database")
         cls.load_archive(
             archive_filename,
             delete_on_completion=True,
@@ -795,7 +798,7 @@ class DatabaseTable(models.Model):
         # Iterate through and grab the columns. Note we don't use get_column_names
         # here because we are attaching relation data as well.
         column_names = [
-            column.name + f" (relation to {column.related_model.__name__})"
+            column.name + f" (relation to {column.related_model.table_name})"
             if column.is_relation
             else column.name
             for column in cls._meta.get_fields()
@@ -818,8 +821,8 @@ class DatabaseTable(models.Model):
         return [
             parent
             for parent in cls.__bases__
-            if hasattr(simmate_mixins, parent.__name__)
-            and parent.__name__ != "DatabaseTable"
+            if hasattr(simmate_mixins, parent.table_name)
+            and parent.table_name != "DatabaseTable"
         ]
 
     @classmethod
@@ -828,7 +831,7 @@ class DatabaseTable(models.Model):
         Grabs the mix-in Tables that were used to make this class and returns
         a list of their names.
         """
-        return [mixin.__name__ for mixin in cls.get_mixins()]
+        return [mixin.table_name for mixin in cls.get_mixins()]
 
     @classmethod
     def get_extra_columns(cls) -> list[str]:
