@@ -3,7 +3,8 @@
 from pathlib import Path
 
 from pymatgen.io.vasp.outputs import Vasprun
-from simmate.database.base_data_types import table_column, Calculation
+
+from simmate.database.base_data_types import Calculation, table_column
 
 
 class CustomizedCalculation(Calculation):
