@@ -176,7 +176,11 @@ class Structure(DatabaseTable):
             * Avogadro
             * 1e-27
             * 1e3,
-            spacegroup_id=structure.get_space_group_info()[1],  # OPTIMIZE
+            # OPTIMIZE SPACEGROUP INFO
+            spacegroup_id=structure.get_space_group_info(
+                symprec=0.1,
+                # angle_tolerance=5.0,
+            )[1],
             formula_full=structure.composition.formula,
             formula_reduced=structure.composition.reduced_formula,
             formula_anonymous=structure.composition.anonymized_formula,
