@@ -12,12 +12,18 @@ def test_calculation_table():
     TestCalculation.show_columns()
 
     # test writing to database
-    calc_db = TestCalculation.from_prefect_id(prefect_flow_run_id="example-id-123")
+    calc_db = TestCalculation.from_run_context(
+        run_id="example-id-123",
+        workflow_name="example.test.workflow",
+    )
     calc_db.save()
 
     # try grabbing the calculation again and make sure it loaded from the
     # database rather than creating a new entry
-    calc_db2 = TestCalculation.from_prefect_id(prefect_flow_run_id="example-id-123")
+    calc_db2 = TestCalculation.from_run_context(
+        run_id="example-id-123",
+        workflow_name="example.test.workflow",
+    )
     assert calc_db.id == calc_db2.id
 
     # grab prefect url for this id
@@ -26,13 +32,26 @@ def test_calculation_table():
         == "https://cloud.prefect.io/simmate/flow-run/example-id-123"
     )
 
+    # and test incorrect passing
+    with pytest.raises(Exception):
+        calc_db2 = TestCalculation.from_run_context(
+            run_id="example-id-123",
+            # workflow_name --> missing but required
+        )
+
 
 @pytest.mark.django_db
 def test_calculation_archives():
 
-    calc_db = TestCalculation.from_prefect_id(prefect_flow_run_id="example-id-123")
+    calc_db = TestCalculation.from_run_context(
+        run_id="example-id-123",
+        workflow_name="example.test.workflow",
+    )
     calc_db.save()
-    calc_db2 = TestCalculation.from_prefect_id(prefect_flow_run_id="example-id-321")
+    calc_db2 = TestCalculation.from_run_context(
+        run_id="example-id-123",
+        workflow_name="example.test.workflow",
+    )
     calc_db2.save()
 
     TestCalculation.objects.to_archive()
