@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from simmate.database.base_data_types import table_column, Structure
+from simmate.database.base_data_types import Structure, table_column
 
 
 class JarvisStructure(Structure):
