@@ -1,9 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from simmate.utilities import get_doc_from_readme
-
-__doc__ = get_doc_from_readme(__file__)
-
 from simmate.database.base_data_types import (
     BandStructureCalc,
     CustomizedCalculation,
@@ -19,6 +15,6 @@ from simmate.database.base_data_types import (
     StaticEnergy,
 )
 from simmate.toolkit.structure_prediction.evolution.database import (
-    EvolutionarySearch,
+    FixedCompositionSearch,
     StructureSource,
 )
