@@ -1,9 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from simmate.utilities import get_doc_from_readme
-
-__doc__ = get_doc_from_readme(__file__)
-
 from pymatgen.analysis.diffusion.neb.pathfinder import DistinctPathFinder
 
 from .migration_hop import MigrationHop
