@@ -1,19 +1,27 @@
 # -*- coding: utf-8 -*-
 
 import logging
+import math
+import traceback
 from pathlib import Path
 
 import pandas
 import plotly.graph_objects as plotly_go
+from rich.progress import track
 
 from simmate.database.base_data_types import DatabaseTable, table_column
 from simmate.toolkit import Composition
+from simmate.toolkit.structure_prediction import (
+    get_known_structures,
+    get_structures_from_prototypes,
+    get_structures_from_substitution_of_known,
+)
 from simmate.toolkit.structure_prediction.evolution.database import StructureSource
 from simmate.utilities import get_directory
 from simmate.workflow_engine.execution import WorkItem
 
 
-class EvolutionarySearch(DatabaseTable):
+class FixedCompositionSearch(DatabaseTable):
     """
     This database table holds all of the information related to an evolutionary
     search and also has convient methods to analyze the data + write output files.
@@ -31,10 +39,12 @@ class EvolutionarySearch(DatabaseTable):
     fitness_field = table_column.CharField(max_length=200)
 
     # Other settings for the search
+    min_structures_exact = table_column.IntegerField()
     max_structures = table_column.IntegerField()
     limit_best_survival = table_column.IntegerField()
     nfirst_generation = table_column.IntegerField()
     nsteadystate = table_column.IntegerField()
+    convergence_limit = table_column.FloatField()
 
     # Key classes to use during the search
     selector_name = table_column.CharField(max_length=200)
@@ -66,7 +76,20 @@ class EvolutionarySearch(DatabaseTable):
 
     def check_stop_condition(self):
 
-        # first see if we've hit our maximum limit for structures.
+        # First, see if we have at least our minimum limit for *exact* structures.
+        # "Exact" refers to the nsites of the structures. We want to ensure at
+        # least N structures with the input/expected number of sites have been
+        # calculated.
+        # {f"{self.fitness_field}__isnull"=False} # when I allow other fitness fxns
+        count_exact = self.individuals_datatable.objects.filter(
+            formula_full=self.composition,
+            workflow_name=self.subworkflow_name,
+            energy_per_atom__isnull=False,
+        ).count()
+        if count_exact < self.min_structures_exact:
+            return False
+
+        # Next, see if we've hit our maximum limit for structures.
         # Note: because we are only looking at the results table, this is really
         # only counting the number of successfully calculated individuals.
         # Nothing is done to stop those that are still running or to count
@@ -78,11 +101,11 @@ class EvolutionarySearch(DatabaseTable):
                 f"(n={self.max_structures})."
             )
             return True
-        # The 2nd stop condition is based on how long we've have the same
+
+        # The next stop condition is based on how long we've have the same
         # "best" individual. If the number of new individuals calculated (without
         # any becoming the new "best") is greater than limit_best_survival, then
         # we can stop the search.
-
         # grab the best individual for reference
         best = self.best_individual
 
@@ -92,9 +115,15 @@ class EvolutionarySearch(DatabaseTable):
 
         # count the number of new individuals added AFTER the best one. If it is
         # more than limit_best_survival, we stop the search.
+        # Note, we look at all structures that have an energy_per_atom greater
+        # than 1meV/atom higher than the best structure. The +1meV ensures
+        # we aren't prolonging the calculation for insignificant changes in
+        # the best structure. Looking at the energy also ensures that we are
+        # only counting completed calculations.
+        # BUG: this filter needs to be updated to fitness_value and not
+        # assume we are using energy_per_atom
         num_new_structures_since_best = self.individuals.filter(
-            # check energies to ensure we only count completed calculations
-            energy_per_atom__gt=best.energy_per_atom,
+            energy_per_atom__gt=best.energy_per_atom + self.convergence_limit,
             created_at__gte=best.created_at,
         ).count()
         if num_new_structures_since_best > self.limit_best_survival:
@@ -107,60 +136,39 @@ class EvolutionarySearch(DatabaseTable):
         return False
 
     def _check_singleshot_sources(self, directory: Path):
-        logging.warning(
-            "Singleshot sources is still in testing. The found structures "
-            "are not submitted as part of the search."
+
+        composition = Composition(self.composition)
+
+        structures_known = get_known_structures(
+            composition,
+            allow_multiples=False,
         )
+        logging.info(
+            f"Generated {len(structures_known)} structures from other databases"
+        )
+        directory_known = get_directory(directory / "known_structures")
+        for i, s in enumerate(structures_known):
+            s.to("cif", directory_known / f"{i}.cif")
 
-        try:
+        structures_sub = get_structures_from_substitution_of_known(
+            composition,
+            allow_multiples=False,
+        )
+        logging.info(f"Generated {len(structures_sub)} structures from substitutions")
+        directory_sub = get_directory(directory / "from_substitutions")
+        for i, s in enumerate(structures_sub):
+            s.to("cif", directory_sub / f"{i}.cif")
 
-            from simmate.toolkit.structure_prediction import (
-                get_known_structures,
-                get_structures_from_prototypes,
-                get_structures_from_substitution_of_known,
-            )
-
-            composition = Composition(self.composition)
-
-            structures_known = get_known_structures(
-                composition,
-                strict_nsites=True,
-            )
-            logging.info(
-                f"Generated {len(structures_known)} structures from other databases"
-            )
-            directory_known = get_directory(directory / "known_structures")
-            for i, s in enumerate(structures_known):
-                s.to("cif", directory_known / f"{i}.cif")
-
-            structures_sub = get_structures_from_substitution_of_known(
-                composition,
-                strict_nsites=True,
-            )
-            logging.info(
-                f"Generated {len(structures_sub)} structures from substitutions"
-            )
-            directory_sub = get_directory(directory / "from_substitutions")
-            for i, s in enumerate(structures_sub):
-                s.to("cif", directory_sub / f"{i}.cif")
-
-            structures_prototype = get_structures_from_prototypes(
-                composition,
-                max_sites=int(composition.num_atoms),
-            )
-            logging.info(
-                f"Generated {len(structures_prototype)} structures from prototypes"
-            )
-            directory_sub = get_directory(directory / "from_prototypes")
-            for i, s in enumerate(structures_prototype):
-                s.to("cif", directory_sub / f"{i}.cif")
-
-        except Exception as error:
-            logging.error(
-                f"Singleshot sources failed with {self.composition}. "
-                "Please report this issue."
-            )
-            raise error
+        structures_prototype = get_structures_from_prototypes(
+            composition,
+            max_sites=int(composition.num_atoms),
+        )
+        logging.info(
+            f"Generated {len(structures_prototype)} structures from prototypes"
+        )
+        directory_sub = get_directory(directory / "from_prototypes")
+        for i, s in enumerate(structures_prototype):
+            s.to("cif", directory_sub / f"{i}.cif")
 
         # Initialize the single-shot sources
         # singleshot_sources = []
@@ -174,7 +182,7 @@ class EvolutionarySearch(DatabaseTable):
         # singleshot_sources_db = []
         # for source in self.singleshot_sources:
         #     source_db = SourceDatatable(
-        #         name=source.__class__.__name__,
+        #         name=source.table_name,
         #         is_steadystate=False,
         #         is_singleshot=True,
         #         search=self.search_datatable,
@@ -214,9 +222,9 @@ class EvolutionarySearch(DatabaseTable):
         # Make sure the proportions sum to 1, otherwise scale them. We then convert
         # these to steady-state integers (and round to the nearest integer)
         sum_proportions = sum(steadystate_source_proportions)
-        if sum_proportions != 1:
+        if not math.isclose(sum_proportions, 1, rel_tol=1e-6):
             logging.warning(
-                "fractions for steady-state sources do not add to 1."
+                "fractions for steady-state sources do not add to 1. "
                 "We have scaled all sources to equal one to fix this."
             )
             steadystate_source_proportions = [
@@ -246,6 +254,7 @@ class EvolutionarySearch(DatabaseTable):
             ]
             is_creator = True if source_name in known_creators else False
             known_transformations = [
+                "ExtremeSymmetry",
                 "from_ase.Heredity",
                 "from_ase.SoftMutation",
                 "from_ase.MirrorMutation",
@@ -317,7 +326,14 @@ class EvolutionarySearch(DatabaseTable):
             )
 
             if nflows_to_submit > 0:
-                logging.info(f"Submitting new individuals from {source_db.name}")
+                logging.info(
+                    f"Submitting {nflows_to_submit} new individuals for "
+                    f"'{source_db.name}'"
+                )
+
+            # disable the logs while we submit
+            logger = logging.getLogger()
+            logger.disabled = True
 
             for n in range(nflows_to_submit):
 
@@ -336,6 +352,9 @@ class EvolutionarySearch(DatabaseTable):
                 source_db.workitem_ids.append(state.pk)
                 source_db.save()
 
+            # reactivate logging
+            logger.disabled = False
+
     # -------------------------------------------------------------------------
     # Core methods that help grab key information about the search
     # -------------------------------------------------------------------------
@@ -374,8 +393,16 @@ class EvolutionarySearch(DatabaseTable):
     def individuals(self):
         # note we don't call "all()" on this queryset yet becuase this property
         # it often used as a "base" queryset (and additional filters are added)
+        composition = Composition(self.composition)
         return self.individuals_datatable.objects.filter(
-            formula_full=self.composition,
+            # You'd expect this filter to be...
+            #   formula_full=self.composition
+            # However, this misses structures that are reduced to a smaller
+            # unitcells during relaxation. Therefore, by default, we need to
+            # include all individuals that have fewer nsites. This is
+            # often what a user wants anyways during searches, so it works out.
+            formula_reduced=composition.reduced_formula,
+            nsites__lte=composition.num_atoms,
             workflow_name=self.subworkflow_name,
         )
 
@@ -428,26 +455,43 @@ class EvolutionarySearch(DatabaseTable):
     def write_summary(self, directory: Path):
         logging.info(f"Writing search summary to {directory}")
 
-        # calls all the key methods defined below
-        best_cifs_directory = get_directory(directory / "best_structures_cifs")
-        self.write_best_structures(100, best_cifs_directory)
-        self.write_individuals_completed(directory)
-        self.write_individuals_completed_full(directory)
-        self.write_best_individuals_history(directory)
-        self.write_individuals_incomplete(directory)
-        self.write_convergence_plot(directory)
-        self.write_final_fitness_plot(directory)
-        self.write_subworkflow_times_plot(directory)
+        # If the output fails to write, we have a non-critical issue that
+        # doesn't affect the search. We therefore don't want to raise an
+        # error here -- but instead warn the user and then continue the search
+        try:
+            # calls all the key methods defined below
+            best_cifs_directory = get_directory(directory / "best_structures_cifs")
+            self.write_best_structures(100, best_cifs_directory)
+            self.write_individuals_completed(directory)
+            self.write_individuals_completed_full(directory)
+            self.write_best_individuals_history(directory)
+            self.write_individuals_incomplete(directory)
+            self.write_convergence_plot(directory)
+            self.write_final_fitness_plot(directory)
+            self.write_subworkflow_times_plot(directory)
 
-        # BUG: This is only for "relaxation.vasp.staged", which the assumed
-        # workflow for now.
-        self.subworkflow.write_series_convergence_plot(
-            directory=directory,
-            formula_full=self.composition,
-            energy_per_atom__isnull=False,
-        )
+            # BUG: This is only for "relaxation.vasp.staged", which the assumed
+            # workflow for now.
+            composition = Composition(self.composition)
+            self.subworkflow.write_series_convergence_plot(
+                directory=directory,
+                # See `individuals` method for why we use these filters
+                formula_reduced=composition.reduced_formula,
+                nsites__lte=composition.num_atoms,
+                energy_per_atom__isnull=False,
+            )
 
-        logging.info("Done writing summary.")
+            logging.info("Done writing summary.")
+
+        except Exception:
+            logging.warning(
+                "Failed to write the output summary. This issue will be silenced "
+                "to avoid stopping the search. But please report the following "
+                "error to our github: https://github.com/jacksund/simmate/issues/"
+            )
+
+            # prints the most recent exception traceback
+            traceback.print_exc()
 
     # -------------------------------------------------------------------------
     # Methods for deserializing objects. Consider moving to the toolkit methods
@@ -502,13 +546,24 @@ class EvolutionarySearch(DatabaseTable):
         # if the directory is filled, we need to delete all the files
         # before writing the new ones.
         for file in directory.iterdir():
-            file.unlink()
+            try:
+                file.unlink()
+            except OSError:
+                logging.warning("Unable to delete a CIF file: {file}")
+                logging.warning(
+                    "Updating the 'best structures' directory involves deleting "
+                    "and re-writing all CIF files each cycle. If you have a file "
+                    "open while this step occurs, then you'll see this warning."
+                    "Close your file for this to go away."
+                )
 
         best = self.get_nbest_indiviudals(nbest)
         structures = best.only("structure_string", "id").to_toolkit()
         for rank, structure in enumerate(structures):
+            rank_cleaned = str(rank).zfill(2)  # converts 1 to 01
             structure_filename = (
-                directory / f"rank-{rank}__id-{structure.database_object.id}.cif"
+                directory
+                / f"rank-{str(rank_cleaned)}__id-{structure.database_object.id}.cif"
             )
             structure.to("cif", structure_filename)
 
@@ -693,18 +748,16 @@ class EvolutionarySearch(DatabaseTable):
             for _, s in structures_dataframe.iterrows()
         ]
 
-        from tqdm import tqdm
-
         structures_dataframe["fingerprint"] = [
             numpy.array(featurizer.featurize(s.structure))
-            for _, s in tqdm(structures_dataframe.iterrows())
+            for _, s in track(structures_dataframe.iterrows())
         ]
 
         fingerprint_known = numpy.array(featurizer.featurize(structure_known))
 
         structures_dataframe["fingerprint_distance"] = [
             numpy.linalg.norm(fingerprint_known - s.fingerprint)
-            for _, s in tqdm(structures_dataframe.iterrows())
+            for _, s in track(structures_dataframe.iterrows())
         ]
 
         # There's only one plot here, no subplot. So we make the scatter
