@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
 
 import logging
-
-# BUG: This prints a tqdm error so we silence it here.
 import warnings
 
 import numpy
 from django.utils import timezone
-from tqdm import tqdm
+from rich.progress import track
 
+# BUG: This prints a tqdm error so we silence it here.
 with warnings.catch_warnings(record=True):
     from matminer.featurizers.site import CrystalNNFingerprint
 
@@ -18,13 +17,15 @@ from matminer.featurizers.structure.sites import (  # PartialsSiteStatsFingerpri
     SiteStatsFingerprint,
 )
 
+from simmate.toolkit.validators.base import Validator
+
 logging.warning(
     "PartialsSiteStatsFingerprint current acts as a SiteStatsFingerprint. "
     "We are waiting on a new MatMiner release to fix this issue."
 )
 
 
-class PartialCrystalNNFingerprint:
+class PartialCrystalNNFingerprint(Validator):
     def __init__(
         self,
         composition,
@@ -72,7 +73,7 @@ class PartialCrystalNNFingerprint:
             self.fingerprint_database = numpy.array(
                 [
                     self.featurizer.featurize(structure)
-                    for structure in tqdm(structure_pool)
+                    for structure in track(structure_pool)
                 ]
             )
 
@@ -143,7 +144,7 @@ class PartialCrystalNNFingerprint:
         )
 
         # If there aren't any new structures, just exit without printing the
-        # message and tqdm progress bar below
+        # message and progress bar
         if not new_structures:
             return
 
@@ -152,7 +153,7 @@ class PartialCrystalNNFingerprint:
         )
 
         # calculate each fingerprint and add it to the database
-        for structure in tqdm(new_structures):
+        for structure in track(new_structures):
             fingerprint = numpy.array(self.featurizer.featurize(structure))
             self._add_fingerprint_to_database(fingerprint)
 
