@@ -6,6 +6,7 @@ import traceback
 
 import cloudpickle  # needed to serialize Prefect workflow runs and tasks
 from django.db import transaction
+from rich import print
 
 from simmate.workflow_engine.execution.database import WorkItem
 
@@ -13,11 +14,13 @@ from simmate.workflow_engine.execution.database import WorkItem
 # starts up.
 # This uses "Small Slant" from https://patorjk.com/software/taag/
 HEADER_ART = r"""
+=====================================================================
    _____                  __        _      __         __
   / __(_)_ _  __ _  ___ _/ /____   | | /| / /__  ____/ /_____ ____
  _\ \/ /  ' \/  ' \/ _ `/ __/ -_)  | |/ |/ / _ \/ __/  '_/ -_) __/
 /___/_/_/_/_/_/_/_/\_,_/\__/\__/   |__/|__/\___/_/ /_/\_\\__/_/
 
+=====================================================================
 """
 
 
@@ -27,6 +30,10 @@ class SimmateWorker:
     via the `run_cloud` method.
     """
 
+    # Consider making this a database object so that we can track workers in
+    # the UI and know how many are running. If linked to the database, we could
+    # even send an update for the worker to shut down.
+
     # Ideally, this worker would involve multiple threads threads going. One
     # thread would update the queue database with a "heartbeat" to let it know
     # that it is still working on tasks. The other thread will run the given
@@ -35,9 +42,6 @@ class SimmateWorker:
     # However, if this level of implementation is needed, we should instead
     # switch to using Prefect, which has it built in.
 
-    # Consider making this a database object so that we can track workers in
-    # the UI and know how many are running.
-
     def __init__(
         self,
         # limit of tasks and lifetime of the worker
@@ -91,7 +95,7 @@ class SimmateWorker:
         """
 
         # print the header in the console to let the user know the worker started
-        logging.info("\n" + HEADER_ART)
+        print("[bold cyan]" + HEADER_ART)
 
         # loggin helpful info
         logging.info(f"Starting worker with tags {list(self.tags)}")
@@ -223,7 +227,7 @@ class SimmateWorker:
                             )
 
                             workitem.command_not_found_failures = nfailures
-                            workitem.status = "P"
+                            workitem.status = "P"  # marked as PENDING to retry
                             workitem.save()
                     logging.info("Shutting down to prevent repeated issues.")
                     return
@@ -245,8 +249,9 @@ class SimmateWorker:
             with transaction.atomic():
                 # pickle the result and update the workitem's result and status
                 # !!! should I have the pickle inside of a Try?
-                workitem.result = result_pickled
-                workitem.status = "F"
+                workitem.result_binary = result_pickled
+                # mark as finished or errored depending on result value
+                workitem.status = "E" if isinstance(result, Exception) else "F"
                 workitem.save()
 
             # mark down that we've completed one WorkItem
