@@ -1,176 +1,5 @@
 # -*- coding: utf-8 -*-
 
-"""
-# The Supervised-Staged-Shell Workflow (aka "S3Workflow")
-
-This class contains the core functionality to **supervise** a **staged** workflow
-involving some **shell** command.
-
-Let's breakdown what this means...
-
-A *shell* command is a single call to some external program. For example,
-VASP requires that we call the "vasp_std > vasp.out" command in order to run a
-calculation. We consider calling external programs a *staged* task made
-up of three steps:
-
-- setup = writing any input files required for the program
-- execution = actually calling the command and running our program
-- workup = loading data from output files back into python
-
-And for *supervising* the task, this means we monitor the program while the
-execution stage is running. So once a program is started, Simmate can check
-output files for common errors/issues -- even while the other program is still
-running. If an error is found, we stop the program, fix the issue, and then 
-restart it.
-
-
-<!--
-TODO: Make a simple diagram to visualize the overall process and add it here.
-It will be similar to Custodian's, but we don't have a list of jobs here.
-https://materialsproject.github.io/custodian/index.html#usage
-The steps are...
-
-- Write Input Files based on custom+defualt settings
-- Run the calculation by calling the program
-- Load ouput files
-- check for errors
-- [correct them, rerun]
-- postprocess/analysis
--->
-
-Running S3Workflows is the same as normal workflows (e.g. using the `run` method),
-and this entire process of supervising, staging, and shell execution is done for you!
-
-
-# S3Workflows for common Calculators
-
-For programs that are commonly used in material science, you should check the
-`simmate.calculators` module and then a given calculator's `workflow` module.
-Many have a subclass of `S3Workflow` already built for you. For example, VASP
-user can take advantage of the following class:
-`simmate.calculators.vasp.workflows.base.VaspWorkflow`
-
-
-
-# Building a custom S3Workflow
-
-Before starting a custom `S3Workflow`, make sure you have read the section 
-above this (on S3Workflows for common Calculators like VASP). You should also 
-have gone through the guides on building a custom `Workflow`.
-
-NOTE: Custom `S3Workflows` must also follow the naming conventions required
-of `Workflow`s
-
-
-## Simple command call
-
-The most basic example of a S3Workflow is just calling some command -- without
-doing anything else (no input files, no error handling, etc.). 
-
-Unlike custom `Workflows` were we defined a `run_config` method, `S3Workflows`
-have a pre-built `run_config` method that carries out the different stages and 
-monitoring of a workflow for us. So all the work is already done for us!
-
-As an example, let's just use the command `echo` to print something:
-    
-``` python
-
-from simmate.workflow_engine import S3Workflow
-
-class Example__Echo__SayHello(S3Workflow):
-    use_database = False  # we aren't using a custom table for now
-    monitor = False  # there is no error handling yet
-    command = "echo Hello"
-
-# behaves like a normal workflow
-state = Example__Echo__SayHello.run()
-result = state.result()
-```
-
-IMPORTANT: Note that  we used "Echo" in our workflow name. This helps the user 
-see what commands or programs will be called when a workflow is ran.
-
-
-## Custom setup and workup
-
-Now what if we'd like to write input files or read output files that are created?
-Here, we need to update our `setup` and `workup` methods:
-
-``` python
-
-from simmate.workflow_engine import S3Workflow
-
-class Example__Echo__SayHello(S3Workflow):
-    
-    use_database = False  # we aren't using a custom table for now
-    monitor = False  # there is no error handling yet
-
-    command = "echo Hello > output.txt"  # adds "Hello" into a new file
-
-    @classmethod
-    def setup(cls, directory, custom_parameter, **kwargs):
-        # The directory given is a pathlib.Path object for the directory
-        # that the command will be called in
-        
-        print("I'm setting things up!")
-        print(f"My new setting value is {cls.some_new_setting}")
-        print(f"My new parameter value is {custom_parmeter}")
-        
-        return  # no need to return anything. Nothing will be done with it.
-
-    @staticmethod
-    def workup(directory):
-        # The directory given is a pathlib.Path object for the directory
-        # that the command will be called in
-        
-        # Simply check that we have a new file
-        output_file = directory / "output.txt"
-        assert output_file.exists()
-        
-        print("I'm working things up!")
-        return "Done!"
-
-task = Example__Echo__SayHello()
-result = task.run()
-```
-
-There are a two important things to note here:
-
-1. It's optional to write new `setup` or `workup` methods. But if you do...
-    - Both `setup` and `workup` method should be either a staticmethod or classmethod
-    - Custom `setup` methods require the `directory` and `**kwargs` input parameters.
-    - Custom `workup` methods require the `directory` input paramter
-2. It's optional to set/overwrite attributes. You can also add new ones too.
-
-Note: S3Workflows for a custom calculator (such `VaspWorkflow` for VASP)
-will often have custom `setup` and `workup` methods already defined for you.
-You can update/override these as you see fit.
-
-For a full (and advanced) example of a subclass take a look at
-`simmate.calculators.vasp.workflows.base.VaspWorkflow` and the tasks that use it like
-`simmate.calculators.vasp.workflows.relaxation.matproj`.
-
-
-# Custom error handling
-
-See the documentation located at `simmate.workflow_engine.error_handler` for
-more information.
-
-
-# Continuation of workflows
-
-This is an experimental feature and for advanced users only. (TODO)
-
-
-# Alternatives
-
-For experts, this class can be viewed as a combination of prefect's ShellTask,
-a custodian Job, and Custodian monitoring. When subclassing this, we can absorb
-functionality of `pymatgen.io.vasp.sets` too. By merging all of these together
-into one class, we make things much easier for users and creating new Tasks.
-
-"""
-
 import logging
 import os
 import platform
