@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
 from simmate.toolkit.structure_prediction.evolution.workflows.all import (
+    StructurePrediction__Python__BinaryComposition,
     StructurePrediction__Python__FixedComposition,
     StructurePrediction__Python__NewIndividual,
+    StructurePrediction__Python__VariableComposition,
 )
